@@ -11,7 +11,7 @@ class API(object):
     POCKET_URL = "https://getpocket.com"
     API_URL = POCKET_URL + "/v3"
 
-    REDIRECT_URL = "https://www.github.com/arvindch/{0}".format(APP_NAME)
+    REDIRECT_URL = "https://www.github.com/achembarpu/{0}".format(APP_NAME)
     ISSUE_URL = REDIRECT_URL + "/issues/new"
     APP_CREATE_URL = "http://getpocket.com/developer/apps/new"
 
