@@ -74,21 +74,24 @@ class Authenticator(object):
 
         create_link = API.APP_CREATE_URL
 
-        Browser.open_new_tab(create_link)
+        if not self._args.no_browser:
+            Browser.open_new_tab(create_link)
 
-        prompt("Step 1:\nCreate an application, via this link :\n` {0} `\n"
+        prompt("Step 1: Create an application, via this link :\n` {0} `\n"
                "Press Enter when done...".format(create_link))
 
-        self._consumer_key = prompt(
-            "Step 2:\nEnter your Consumer Key: ").strip()
+        while not self._consumer_key:
+            self._consumer_key = prompt(
+                "Step 2: Enter your Consumer Key:\n").strip()
 
         self._obtain_request_token()
 
         auth_link = API.get_auth_user_url(self._request_token)
 
-        Browser.open_new_tab(auth_link)
+        if not self._args.no_browser:
+            Browser.open_new_tab(auth_link)
 
-        prompt("Step 3:\nConnect an account, via this link :\n` {0} `\n"
+        prompt("Step 3: Connect an account, via this link :\n` {0} `\n"
                "Press Enter when done...".format(auth_link))
 
         self._obtain_access_token()
